==> radiance-ui-2.0.2.tgz: package/lib/shared-components/selectorButton/test.js <==
import React from 'react';
import { shallow } from 'enzyme';
import renderer from 'react-test-renderer';
import SelectorButton from './index';
describe('<SelectorButton />', function () {
  describe('UI snapshots', function () {
    test('when children is undefined', function () {
      var tree = renderer.create(React.createElement(SelectorButton, {
        checked: false,
        onClick: function onClick() {}
      })).toJSON();
      expect(tree).toMatchSnapshot();
    });
    test('when children is a node', function () {
      var tree = renderer.create(React.createElement(SelectorButton, {
        checked: false,
        onClick: function onClick() {}
      }, "SelectorButton Text")).toJSON();
      expect(tree).toMatchSnapshot();
    });
    test('when checked type is primary', function () {
      var tree = renderer.create(React.createElement(SelectorButton, {
        checked: true,
        onClick: function onClick() {},
        type: "primary"
      }, "SelectorButton Text")).toJSON();
      expect(tree).toMatchSnapshot();
    });
    test('when checked type is secondary', function () {
      var tree = renderer.create(React.createElement(SelectorButton, {
        checked: true,
        onClick: function onClick() {},
        type: "secondary"
      }, "SelectorButton Text")).toJSON();
      expect(tree).toMatchSnapshot();
    });
    test('when is checkbox', function () {
      var tree = renderer.create(React.createElement(SelectorButton, {
        checked: false,
        onClick: function onClick() {},
        selector: "checkbox"
      }, "SelectorButton Text")).toJSON();
      expect(tree).toMatchSnapshot();
    });
  });
  describe('onClick callback', function () {
    it('is invoked on click', function () {
      var spy = jest.fn();
      var wrapper = shallow(React.createElement(SelectorButton, {
        checked: false,
        onClick: spy
      }));
      wrapper.simulate('click');
      expect(spy).toHaveBeenCalled();
    });
  });
});

==> radiance-ui-2.0.7.tgz: package/lib/shared-components/selectorButton/test.js <==
import { jsx as ___EmotionJSX } from "@emotion/core";
import React from 'react';
import { shallow } from 'enzyme';
import renderer from 'react-test-renderer';
import SelectorButton from './index';
describe('<SelectorButton />', function () {
  describe('UI snapshots', function () {
    test('when children is undefined', function () {
      var tree = renderer.create(___EmotionJSX(SelectorButton, {
        checked: false,
        onClick: function onClick() {}
      })).toJSON();
      expect(tree).toMatchSnapshot();
    });
    test('when children is a node', function () {
      var tree = renderer.create(___EmotionJSX(SelectorButton, {
        checked: false,
        onClick: function onClick() {}
      }, "SelectorButton Text")).toJSON();
      expect(tree).toMatchSnapshot();
    });
    test('when checked type is primary', function () {
      var tree = renderer.create(___EmotionJSX(SelectorButton, {
        checked: true,
        onClick: function onClick() {},
        type: "primary"
      }, "SelectorButton Text")).toJSON();
      expect(tree).toMatchSnapshot();
    });
    test('when checked type is secondary', function () {
      var tree = renderer.create(___EmotionJSX(SelectorButton, {
        checked: true,
        onClick: function onClick() {},
        type: "secondary"
      }, "SelectorButton Text")).toJSON();
      expect(tree).toMatchSnapshot();
    });
    test('when is checkbox', function () {
      var tree = renderer.create(___EmotionJSX(SelectorButton, {
        checked: false,
        onClick: function onClick() {},
        selector: "checkbox"
      }, "SelectorButton Text")).toJSON();
      expect(tree).toMatchSnapshot();
    });
  });
  describe('onClick callback', function () {
    it('is invoked on click', function () {
      var spy = jest.fn();
      var wrapper = shallow(___EmotionJSX(SelectorButton, {
        checked: false,
        onClick: spy
      }));
      wrapper.simulate('click');
      expect(spy).toHaveBeenCalled();
    });
  });
});
